yakumo.keystone.v2.endpoint

Package yakumo :: Package keystone :: Package v2 :: Module endpoint |
[hide private]
[frames] | no frames]

# Module endpoint

source code

Resource class and its manager for endpoints in Identity V2 API

Classes | [hide private]
| Resource resource class for endpoints on Identity V2 API
| Manager manager class for endpoints on Identity V2 API

Variables | [hide private]
| ATTRIBUTE_MAPPING = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass obj`...``
| __package__ = ``'``yakumo.keystone.v2``'``

Variables Details | [hide private]

  ### ATTRIBUTE_MAPPING Value:
      [('id', 'id', mapper.Noop), ('public_url', 'publicurl', mapper.Noop),
      ('internal_url', 'internalurl', mapper.Noop), ('admin_url', 'adminurl'
      , mapper.Noop), ('region', 'region', mapper.Noop), ('is_enabled', 'ena
      bled', mapper.Noop), ('service', 'service_id', mapper.Resource('keysto
      ne.service')),]